@@ -3,7 +3,7 @@ package Getopt::optparse;
 use strict;
 use Scalar::Util 'reftype';
 
-our $VERSION = '0.02';
+our $VERSION = '0.05';
  
 $| = 1;
 
@@ -72,22 +72,43 @@ sub parse_args {
             if ($self->{parser}{$key}{default}) {
                 $options{$self->{parser}{$key}{dest}} = $self->{parser}{$key}{default};
             }
+            # Handle count
+            if ($self->{parser}{$key}{action} eq 'count') {
+                $options{$self->{parser}{$key}{dest}} = 0;
+            }
             # Handle store_true
-            if ($self->{parser}{$key}{'action'} eq 'store_true') {
-                if ($self->{cmdline} =~ /$key/) {
+            if ($self->{parser}{$key}{action} eq 'store_true') {
+                if ($self->{cmdline} =~ /$key\s+/) {
                     $options{$self->{parser}{$key}{dest}} = 1;
                 } else {
                     $options{$self->{parser}{$key}{dest}} = 0;
                 }
             }
             else {
-                # Search command lien option
+                # Populate a default of empty scalar, which will evaluate to false.
                 if (! $self->{parser}{$key}{default}) {
                     $options{$self->{parser}{$key}{dest}} = '';
                 }
-                if ($self->{cmdline} =~ /$key=(.*?)\s/) {
-                    if ($1 !~ /^-/) {
-                        $options{$self->{parser}{$key}{dest}} = $1;
+                # Populate a default of blank arrayref, which will evaluate to false.
+                if ($self->{parser}{$key}{action} eq 'append') {
+                    $options{$self->{parser}{$key}{dest}} = [];
+                }
+                if (my @matches = ($self->{cmdline} =~ /$key\s+/g)) {
+                    for my $match (@matches) {
+                        $options{$self->{parser}{$key}{dest}} += 1;
+                    }
+                }
+                # Search command lien option
+                if (my @matches = ($self->{cmdline} =~ /$key=(.*?)\s+/g)) {
+                    if ($self->{parser}{$key}{action} eq 'append') {
+                        for my $match (@matches) {
+                            push @{$options{$self->{parser}{$key}{dest}}}, $match;
+                        }
+                    }
+                    else {
+                        if ($matches[0] !~ /^-/) {
+                            $options{$self->{parser}{$key}{dest}} = $1;
+                        }
                     }
                 }
             }
@@ -139,6 +160,8 @@ sub show_help {
 
 Getopt::optparse - optparse style processing of command line options
 
+This library only supports double dash options: --
+
 =head1 SYNOPSIS
 
     use Getopt::optparse;
@@ -151,13 +174,6 @@ Getopt::optparse - optparse style processing of command line options
             default => 'localhost.localdomain'
         }
     );
-    $parser->add_option(
-        '--username', 
-        {
-            dest => 'username',
-            help => 'Username for new ILO account'
-        }
-    );
     $parser->add_option( 
         '--global',
         dest    => 'global',
@@ -165,6 +181,22 @@ Getopt::optparse - optparse style processing of command line options
         help    => 'Show global',
         default => 0
     )
+    $parser->add_option(
+        '--username', 
+        {
+            dest   => 'username',
+            action => 'append',
+            help   => 'Usernames to analyze'
+        }
+    );
+    $parser->add_option(
+        '--v', 
+        {
+            dest   => 'verbose',
+            action => 'count',
+            help   => 'Increment verbosity'
+        }
+    );
 
     my $options = $parser->parse_args();
     printf("Hostname is: %s\n", $options->{hostname});
@@ -234,7 +266,23 @@ Text message displayed when --help is found on command line.
 
 =item action (optional)
 
-Presently only store_true supported.  Using this makes dest true or false.  (0 or 1)
+The following actions are supported.
+
+=over 4
+
+=item store_true
+
+Using this makes dest true or false.  (0 or 1).  If the option is found.
+
+=item append
+
+Using this appends each occurrance of an option to an array reference.
+
+=item count
+
+using this increments dest by one for every occurrence.
+
+=back
 
 =back
 
